#
# spec file for package sdbus-cpp
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2021-2024 Luca Boccassi <bluca@debian.org>
# Copyright (c) 2020-2021 RedHat Inc.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global version_major 1
%global version_minor 5
%global version_micro 0

Name:           sdbus-cpp
Version:        %{version_major}.%{version_minor}.%{version_micro}
Release:        1.2
Summary:        High-level C++ D-Bus library
License:        LGPL-2.1-only
Group:          Development/Libraries/C and C++

URL:            https://github.com/Kistler-Group/sdbus-cpp
Source0:        %{url}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz

BuildRequires:  cmake >= 3.12
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig(libsystemd) >= 236

%description
High-level C++ D-Bus library for Linux designed to provide easy-to-use
yet powerful API in modern C++

%package -n libsdbus-c++1
Summary:        Shared library for %{name}
Group:          Development/Libraries/C and C++

%description -n libsdbus-c++1
Shared library files for %{name}.

%package devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       libsdbus-c++1 = %{version}

%description devel
CMake, pkg-config, headers and other development files for %{name}.

%package devel-doc
Summary:        Developer documentation for %{name}
Group:          Development/Libraries/C and C++
BuildArch:      noarch
BuildRequires:  doxygen

%description devel-doc
READMEs and generated doxygen documentation for %{name}

%package xml2cpp
Summary:        Stub code generator for sdbus-c++
Group:          Development/Libraries/C and C++
Requires:       libsdbus-c++1 = %{version}
BuildRequires:  pkgconfig(expat)

%description xml2cpp
The stub code generator for generating the adapter and proxy interfaces
out of the D-Bus IDL XML description.

%prep
%autosetup -n %{name}-%{version}

%build
%cmake . \
    -DCMAKE_INSTALL_DOCDIR=/usr/share/doc/packages/sdbus-c++ \
    -DCMAKE_BUILD_TYPE=Release \
    -DBUILD_CODE_GEN=ON \
    -DBUILD_DOXYGEN_DOC=ON
%cmake_build
%cmake_build doc

%install
%cmake_install

%post -n libsdbus-c++1 -p /sbin/ldconfig

%postun -n libsdbus-c++1 -p /sbin/ldconfig

%files -n libsdbus-c++1
%license COPYING
%{_libdir}/libsdbus-c++.so.*

%files devel
%dir %{_libdir}/cmake/sdbus-c++
%dir %{_libdir}/cmake/sdbus-c++-tools
%dir %{_docdir}/sdbus-c++
%doc %{_docdir}/sdbus-c++/AUTHORS
%doc %{_docdir}/sdbus-c++/ChangeLog
%doc %{_docdir}/sdbus-c++/NEWS
%doc %{_docdir}/sdbus-c++/README
%doc %{_docdir}/sdbus-c++/COPYING
%{_libdir}/cmake/sdbus-c++*
%{_libdir}/pkgconfig/sdbus-c++*
%{_libdir}/libsdbus-c++.so
%{_includedir}/*

%files devel-doc
%dir %{_docdir}/sdbus-c++
%dir %{_docdir}/sdbus-c++/html
%doc %{_docdir}/sdbus-c++/html/*
%doc %{_docdir}/sdbus-c++/README.md
%doc %{_docdir}/sdbus-c++/sdbus-c++-class-diagram.png
%doc %{_docdir}/sdbus-c++/sdbus-c++-class-diagram.uml
%doc %{_docdir}/sdbus-c++/systemd-dbus-config.md
%doc %{_docdir}/sdbus-c++/using-sdbus-c++.md
%license COPYING

%files xml2cpp
%{_bindir}/sdbus-c++-xml2cpp
%license COPYING

%changelog
* Mon Feb 26 2024 Luca Boccassi <bluca@debian.org>
- Update to new version 1.5.0:
  - Improve handling of exceptions from callback handlers
  - Add support for async registration of matches
  - Correctly add libsystemd dependency to pkgconfi
  - Fix request name signal handling issue
  - Add INSTALL_TESTS CMake option
  - Minor UnixFd cleanups
  - Additional little fixes and updates in code, build system, CI, and documentation
* Wed Oct 11 2023 Luca Boccassi <bluca@debian.org>
- Update to new version 1.4.0:
  - Implement API for convenient asynchronous property get/set on the client-side
  - Add support for FreeBSD systems (including support for basu implementation of sd-bus on non-systemd machines)
  - Add support for direct, peer-to-peer connections
  - Add option to create IConnection directly from an underlying sd_bus instance
  - Some additional CMake-related and code bug fixes
* Sat Aug 26 2023 Luca Boccassi <bluca@debian.org>
- Update to new version 1.3.0:
  - Add support for light-weight proxies (proxies without own event loop threads)
  - Extend documentation with explicit mapping between D-Bus and corresponding C++ types
  - Support move semantics in generated adaptor and proxy classes
  - Adaptations for libsystemd v251
  - Fix for proper complete sending of long D-Bus messages by explicitly flushing them
  - Add support for std::future-based async calls
  - Fix race condition in async Proxy::callMethod
  - Fix pseudo-connection static lifetime issue with Phoenix pattern
  - Speed up performance of of serialization of arrays of trivial D-Bus types
  - Make sdbus::Struct a tuple-like class, so it's usable wherever std::tuple is
  - Add support for std::array, std::span and std::unordered_map as additional C++ types for D-Bus array types
  - Add support for libelogind as an addition to libsystemd
  - Add support for std::future-based async methods in codegen tool
  - Additional little fixes and improvements in code, build system, CI, and documentation
* Tue Aug  9 2022 Luca Boccassi <bluca@debian.org>
- Update to new version 1.2.0:
  - Add support for match rules
  - Add support for session bus connection at custom address
  - Add CMake variable for extra libsystemd config options
  - Use pseudo D-Bus connection for plain messages
  - Rename dont_request_slot tag to floating_slot
  - Add validity checks for names and paths
  - Remove executable flag from source files
  - Detect missing type after array declaration
  - Fix invalid assert on event fd
  - Enable move for ObjectPath and Signature
  - Add printer for std::chrono in googletest v1.11.0
  - Fix potential undefined behavior in creation of sdbus::Error
  - Additional little fixes and improvements in code, build system, and documentation
* Wed Dec 22 2021 Luca Boccassi <bluca@debian.org>
- Update to new version 1.1.0:
  - Fix timeout handling for asynchronous method calls
  - Add support for unregistering signal handler
  - Add support for chrono literals in sdbus-c++-xml2cpp generator
  - Additional little fixes and improvements in code, build system, and documentation
* Mon Oct 25 2021 Luca Boccassi <bluca@debian.org>
- Update to new version 1.0.0
- Bump package name for new SOVERSION
* Thu Oct 21 2021 Luca Boccassi <bluca@debian.org>
- Update to new version 0.9.0
- Drop patch merged upstream: 0001-Find-and-link-against-pthread.patch
- Use more wildcards to pick files to package
* Thu Apr  1 2021 Luca Boccassi <bluca@debian.org>
- Initial packaging of version 0.8.3
- Imported from Fedora https://src.fedoraproject.org/rpms/systemd/blob/rawhide/f/systemd.spec
- Change source tarball name to sdbus-cpp-<version>.tar.gz
- Add 0001-Find-and-link-against-pthread.patch to fix build failure
- Use cmake_build doc, without --target, unsupported on SUSE
- Set CMAKE_INSTALL_DOCDIR to /usr/share/doc/packages/sdbus-c++ to match _docdir
- Explicitly list files in document page, wildcard not supported
- Use SPDX license identifier
- Set Group
- Add ldconfig post/postun
- Change main package name to libsdbus-c++0
- Move cmake files to -devel package
- Move changelog to sdbus-cpp.changes file
- Move AUTHORS/ChangeLog/NEWS/README to -devel package
- Apply changes from 'osc service localrun format_spec_file'
- Remove 'undefine __cmake_in_source_build', not needed
- Fix dependency from -devel/-bin packages to lib package
